@@ -278,7 +278,7 @@ def find_executions(classname=None, launched_by=None, executable=None, project=N
     if launched_by is not None:
         query["launchedBy"] = launched_by
     if executable is not None:
-        if isinstance(executable, (DXApplet, DXApp, DXAnalysisWorkflow)):
+        if isinstance(executable, (DXApplet, DXApp, DXWorkflow)):
             query["executable"] = executable.get_id()
         else:
             query["executable"] = executable
@@ -523,10 +523,10 @@ def _find_one(method, zero_ok=False, more_ok=True, **kwargs):
     kwargs["limit"] = 1 if more_ok else 2
     response = method(**kwargs)
     try:
-        result = response.next()
+        result = next(response)
         if not more_ok:
             try:
-                response.next()
+                next(response)
                 raise DXSearchError("Expected one result, but found more: "+str(kwargs))
             except StopIteration:
                 pass
